package pro.litvinovg.w2phtml.gui;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Map.Entry;
import java.util.prefs.Preferences;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import static pro.litvinovg.w2phtml.gui.Contstants.*;


public class PreferencesStorage {
	
	private static final Logger logger = LoggerFactory.getLogger(PreferencesStorage.class);
	private Map<String,UIPreferences> preferences;

	private Preferences storage;

	public PreferencesStorage() {
		initializeDefaults();
		storage = Preferences.userRoot();
	}
	
	private void initializeDefaults() {
		preferences = new HashMap();
		initializeDefault();
	}

	private void initializeDefault() {
		initializeDefaultHTML();
		initializeDefaultEpub();
		initializeDefaultRDF();
	}

	private void initializeDefaultHTML() {
		UIPreferences prefs = new UIPreferences();
		add(PREF_RESOLUTIONS, new String[]{"0","72","150","300","600","1200","2400"} , prefs);
		add(PREF_DEFAULT_IMAGE_RESOLUTION,"2", prefs);
		add(PREF_USE_MATHJAX,"true", prefs);
		add(PREF_IGNORE_EMPTY_PARS,"false", prefs);
		add(PREF_IGNORE_HARD_BREAKS,"false", prefs);
		add(PREF_GREENSTONE_TAGS,"false", prefs);
		add(PREF_LETTER_SPACING,"0.15",prefs);
		add(PREF_INLINE_STYLES,"true", prefs);
		add(PREF_EMBED_RASTER,"true", prefs);
		add(PREF_EMBED_VECTOR,"true", prefs);
		add(PREF_PAGEBREAK_STYLES,DEFAULT_PAGEBREAK_STYLE_SETTINGS,prefs);
		add(PREF_PAGINATION,"true",prefs);

		preferences.put(HTML, prefs);
	}
	

	private void initializeDefaultEpub() {
		UIPreferences prefs = new UIPreferences();
		add(PREF_RESOLUTIONS, new String[]{"0","72","150","300","600","1200","2400"} , prefs);
		add(PREF_DEFAULT_IMAGE_RESOLUTION,"2", prefs);
		add(PREF_USE_MATHJAX,"true", prefs);
		add(PREF_IGNORE_EMPTY_PARS,"false", prefs);
		add(PREF_IGNORE_HARD_BREAKS,"false", prefs);
		add(PREF_LETTER_SPACING,"0.15",prefs);
		add(PREF_INLINE_STYLES,"true", prefs);
		add(PREF_EMBED_RASTER,"true", prefs);
		add(PREF_EMBED_VECTOR,"true", prefs);
		add(PREF_SCALING, SCALING_DEFAULT_VALUE, prefs);
		add(PREF_PAGEBREAK_STYLES,DEFAULT_PAGEBREAK_STYLE_SETTINGS,prefs);
		add(PREF_PAGINATION,"true",prefs);
		
		preferences.put(EPUB, prefs);
	}

	private void initializeDefaultRDF() {
		UIPreferences prefs = new UIPreferences();
		add(PREF_PUBLICATION_TYPES, new String[]{"elenphArticle", "encArticle", "book", "journal"} , prefs);
		add(PREF_RESOLUTIONS, new String[]{"0","72","150","300","600","1200","2400"} , prefs);
		add(PREF_DEFAULT_IMAGE_RESOLUTION,"2", prefs);
		add(PREF_DEFAULT_PUBLICATION_TYPE,"0", prefs);
		add(PREF_USE_MATHJAX,"true", prefs);
		add(PREF_IGNORE_EMPTY_PARS,"false", prefs);
		add(PREF_IGNORE_HARD_BREAKS,"false", prefs);
		add(PREF_LETTER_SPACING,"0.15",prefs);
		add(PREF_INLINE_STYLES,"true", prefs);
		add(PREF_EMBED_RASTER,"true", prefs);
		add(PREF_EMBED_VECTOR,"true", prefs);
		add(PREF_PAGEBREAK_STYLES,DEFAULT_PAGEBREAK_STYLE_SETTINGS,prefs);
		add(PREF_PAGINATION,"true",prefs);

		preferences.put(RDF, prefs);
	}

	private void add(String key, String[] strings,UIPreferences prefs) {
		ArrayList<String> values = new ArrayList<String>(Arrays.asList(strings));
		prefs.put(key, values);
	}
	
	private void add(String key, String value,UIPreferences prefs) {
		ArrayList<String> values = new ArrayList<String>();
		values.add(value);
		prefs.put(key, values);
	}

	public UIPreferences get(String name, String type) {
		if (preferences.containsKey(name)) {
			return preferences.get(name);	
		} else {
			return preferences.get(type);
		}
		
	}
	
	public void setSourceFileName(String fileName) {
		Iterator<Entry<String, UIPreferences>> it = preferences.entrySet().iterator();
		while (it.hasNext()) {
			Entry<String, UIPreferences> pair = it.next();
			UIPreferences value = (UIPreferences) pair.getValue();
			value.setSourceFileName(fileName);
		}
	}
}
	

