package w2phtml.pageSplitters;

import org.w3c.dom.Node;
import static w2phtml.office.XMLString.*;
import pro.litvinovg.xml.Debug;
import w2phtml.office.OfficeReader;

public class SplitFactory {
	private OfficeReader officeReader;
	public SplitFactory(OfficeReader ofr){
		this.officeReader = ofr;
	}
	public SplitResults split(Node node) {
		if(node == null) {
			System.out.println("Error. Node is null.");
			Debug.printStackTrace();
			System.exit(1);
		}
		String nodeName = node.getNodeName();
		ISplitter splitter = null;
		if (nodeName.contentEquals(TEXT_SPAN)) {
			splitter = new SpanSplitter(officeReader, this);
		} else
		if (nodeName.contentEquals(TEXT_P) || nodeName.contentEquals(TEXT_H)) {
			splitter = new ParagraphSplitter(officeReader, this);
		} else
		if (nodeName.contentEquals(TEXT_NOTE_BODY) || nodeName.contentEquals(OFFICE_TEXT)) {
			splitter = new TextSplitter(officeReader, this);
		} else
		if (nodeName.contentEquals(TEXT_ILLUSTRATION_INDEX)) {
			splitter = new IllustrationIndexSplitter(officeReader, this);
		} else
		if (nodeName.contentEquals(TEXT_INDEX_BODY)) {
			splitter = new IndexBodySplitter(officeReader, this);
		} else
		if (nodeName.contentEquals(TEXT_ALPHABETICAL_INDEX)) {
			splitter = new ABIndexSplitter(officeReader, this);
		} else
		if (nodeName.contentEquals(TABLE_TABLE)) {
			splitter = new TableSplitter(officeReader, this);
		} else
		if (nodeName.contentEquals(TABLE_TABLE_ROW)) {
			splitter = new TableRowSplitter(officeReader, this);
		} else
		if (nodeName.contentEquals(TABLE_TABLE_ROWS)) {
			splitter = new TableRowsSplitter(officeReader, this);
		} else
		if (nodeName.contentEquals(TEXT_LIST)) {
			splitter = new ListSplitter(officeReader, this);
		} else
		if (nodeName.contentEquals(TEXT_SECTION)) {
			splitter = new SectionSplitter(officeReader, this);
		} else
		if (nodeName.contentEquals(TEXT_LIST_ITEM)) {
			splitter = new ListItemSplitter(officeReader, this);
		} else
		if (nodeName.contentEquals(TABLE_TABLE_ROW_GROUP)) {
			splitter = new TableRowGroupSplitter(officeReader, this);
		} else
		if (nodeName.contentEquals(TABLE_TABLE_CELL) || nodeName.contentEquals(TABLE_COVERED_TABLE_CELL)) {
			splitter = new TableCellSplitter(officeReader, this);
		} 
		
		
		if (splitter == null) {
			System.out.println("Error. Splitter for element " + nodeName + " is not implemented, yet. Exit.");
			System.exit(1);
		}
		return splitter.Split(node);
	}
}
